@@ -45,12 +45,10 @@ parse_server_response                   (const gchar       *response,
     {
     case SERVICE_TWITPIC:
     case SERVICE_IMGLY:
-    case SERVICE_POSTEROUS:
       rootid = "image";
       urlid  = "url";
       break;
     case SERVICE_MOBYPICTURE:
-    case SERVICE_TWITGOO:
     case SERVICE_YFROG:
       rootid = "rsp";
       urlid  = "mediaurl";
@@ -68,6 +66,12 @@ parse_server_response                   (const gchar       *response,
         if (xmlStrEqual (iter->name, (xmlChar *) rootid))
           root = iter;
 
+      /* The Mobypicture response includes an extra <media> node */
+      if (root != NULL && service == SERVICE_MOBYPICTURE)
+        for (iter = root->xmlChildrenNode; iter; iter = iter->next)
+          if (xmlStrEqual (iter->name, (xmlChar *) "media"))
+            root = iter;
+
       if (root != NULL)
         for (iter = root->xmlChildrenNode; iter && !url; iter = iter->next)
           if (xmlStrEqual (iter->name, (xmlChar *) urlid))
@@ -244,16 +248,12 @@ get_twitter_pic_service                 (SharingEntry *entry)
   servicename = sharing_entry_get_option (entry, "service");
   if (servicename)
     {
-      if (g_str_equal (servicename, "twitgoo"))
-        service = SERVICE_TWITGOO;
-      else if (g_str_equal (servicename, "twitter"))
+      if (g_str_equal (servicename, "twitter"))
         service = SERVICE_TWITTER;
       else if (g_str_equal (servicename, "mobypicture"))
         service = SERVICE_MOBYPICTURE;
       else if (g_str_equal (servicename, "imgly"))
         service = SERVICE_IMGLY;
-      else if (g_str_equal (servicename, "posterous"))
-        service = SERVICE_POSTEROUS;
       else if (g_str_equal (servicename, "yfrog"))
         service = SERVICE_YFROG;
     }
@@ -395,19 +395,9 @@ twitmulti_share_file                    (SharingTransfer *transfer,
               sharing_http_add_req_multipart_data (http, "key", MOBYPICTURE_API_KEY, -1, "text/plain");
               posturl = "https://api.mobypicture.com/2.0/upload.xml";
               break;
-            case SERVICE_TWITGOO:
-              posturl = "http://twitgoo.com/api/upload";
-              break;
             case SERVICE_IMGLY:
               posturl = "http://img.ly/api/2/upload.xml";
               break;
-            case SERVICE_POSTEROUS:
-              if (description)
-                sharing_http_add_req_multipart_data (http, "body", description, -1, "text/plain");
-              sharing_http_add_req_multipart_data (http, "source", APP_NAME, -1, "text/plain");
-              sharing_http_add_req_multipart_data (http, "sourceLink", APP_URL, -1, "text/plain");
-              posturl = "https://posterous.com/api2/upload.xml";
-              break;
             case SERVICE_YFROG:
               sharing_http_add_req_multipart_data (http, "key", YFROG_API_KEY, -1, "text/plain");
               posturl = "https://yfrog.com/api/xauth_upload";
