@@ -29,9 +29,7 @@ typedef enum {
   SERVICE_TWITPIC,        /* http://dev.twitpic.com/docs/2/upload/                             */
   SERVICE_MOBYPICTURE,    /* http://developers.mobypicture.com/documentation/2-0/upload/       */
   SERVICE_IMGLY,          /* http://img.ly/api/docs                                            */
-  SERVICE_POSTEROUS,      /* http://posterous.com/api/twitter                                  */
-  SERVICE_YFROG,          /* http://code.google.com/p/imageshackapi/wiki/TwitterAuthentication */
-  SERVICE_TWITGOO         /* http://twitgoo.com/docs/Content/Developer/upload.htm              */
+  SERVICE_YFROG           /* http://code.google.com/p/imageshackapi/wiki/TwitterAuthentication */
 } TwitterPicService;
 
 gboolean
